from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import Union

if TYPE_CHECKING:
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_security import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Security
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_mining import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Mining
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_farming_agriculture import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FarmingAgriculture
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_real_estate import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0RealEstate
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_travel_tourism import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0TravelTourism
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_publishing import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Publishing
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_artificial_intelligence import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtificialIntelligence
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_construction import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Construction
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_automotive import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Automotive
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_utilities import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Utilities
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_entertainment import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Entertainment
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_energy import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Energy
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_science_engineering import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ScienceEngineering
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_gaming import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Gaming
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_information_technology import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0InformationTechnology
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_nonprofit import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Nonprofit
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_administrative_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AdministrativeServices
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_government import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Government
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_finance import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Finance
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_events import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Events
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_insurance import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Insurance
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_environmental import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Environmental
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_design import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Design
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consumer_goods import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerGoods
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_education import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Education
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_business_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0BusinessServices
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_hospitality import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hospitality
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_hardware import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hardware
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_arts_music import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtsMusic
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_cloud import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Cloud
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_life_sciences import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0LifeSciences
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_software import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Software
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_trade import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Trade
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_media import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Media
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_retail import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Retail
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consulting import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Consulting
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_transportation import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Transportation
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_healthcare import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Healthcare
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_marketing_advertising import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0MarketingAdvertising
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_venture_capital import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0VentureCapital
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_industrials import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Industrials
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_telecom import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Telecom
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_sports import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Sports
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_logistics import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Logistics
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consumer_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerServices
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_manufacturing import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Manufacturing
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_aerospace_military import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AerospaceMilitary
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_food_beverage import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FoodBeverage
  from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_legal import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Legal





T = TypeVar("T", bound="PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0")



@_attrs_define
class PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0:
    """ 
        Attributes:
            administrative_services (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0S
                tandardIndustriesStatsType0AdministrativeServices]):
            aerospace_military (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0Standa
                rdIndustriesStatsType0AerospaceMilitary]):
            artificial_intelligence (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0S
                tandardIndustriesStatsType0ArtificialIntelligence]):
            arts_music (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndust
                riesStatsType0ArtsMusic]):
            automotive (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndust
                riesStatsType0Automotive]):
            business_services (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0Standar
                dIndustriesStatsType0BusinessServices]):
            cloud (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Cloud]):
            construction (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndu
                striesStatsType0Construction]):
            consulting (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndust
                riesStatsType0Consulting]):
            consumer_goods (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIn
                dustriesStatsType0ConsumerGoods]):
            consumer_services (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0Standar
                dIndustriesStatsType0ConsumerServices]):
            design (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Design]):
            education (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustr
                iesStatsType0Education]):
            energy (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Energy]):
            entertainment (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardInd
                ustriesStatsType0Entertainment]):
            environmental (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardInd
                ustriesStatsType0Environmental]):
            events (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Events]):
            farming_agriculture (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0Stand
                ardIndustriesStatsType0FarmingAgriculture]):
            finance (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Finance]):
            food_beverage (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardInd
                ustriesStatsType0FoodBeverage]):
            gaming (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Gaming]):
            government (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndust
                riesStatsType0Government]):
            hardware (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hardware]):
            healthcare (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndust
                riesStatsType0Healthcare]):
            hospitality (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndus
                triesStatsType0Hospitality]):
            industrials (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndus
                triesStatsType0Industrials]):
            information_technology (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0St
                andardIndustriesStatsType0InformationTechnology]):
            insurance (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustr
                iesStatsType0Insurance]):
            legal (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Legal]):
            life_sciences (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardInd
                ustriesStatsType0LifeSciences]):
            logistics (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustr
                iesStatsType0Logistics]):
            manufacturing (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardInd
                ustriesStatsType0Manufacturing]):
            marketing_advertising (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0Sta
                ndardIndustriesStatsType0MarketingAdvertising]):
            media (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Media]):
            mining (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Mining]):
            nonprofit (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustr
                iesStatsType0Nonprofit]):
            publishing (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndust
                riesStatsType0Publishing]):
            real_estate (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndus
                triesStatsType0RealEstate]):
            retail (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Retail]):
            science_engineering (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0Stand
                ardIndustriesStatsType0ScienceEngineering]):
            security (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Security]):
            software (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Software]):
            sports (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Sports]):
            telecom (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Telecom]):
            trade (Union[Unset,
                PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Trade]):
            transportation (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIn
                dustriesStatsType0Transportation]):
            travel_tourism (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIn
                dustriesStatsType0TravelTourism]):
            utilities (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustr
                iesStatsType0Utilities]):
            venture_capital (Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardI
                ndustriesStatsType0VentureCapital]):
     """

    administrative_services: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AdministrativeServices'] = UNSET
    aerospace_military: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AerospaceMilitary'] = UNSET
    artificial_intelligence: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtificialIntelligence'] = UNSET
    arts_music: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtsMusic'] = UNSET
    automotive: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Automotive'] = UNSET
    business_services: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0BusinessServices'] = UNSET
    cloud: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Cloud'] = UNSET
    construction: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Construction'] = UNSET
    consulting: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Consulting'] = UNSET
    consumer_goods: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerGoods'] = UNSET
    consumer_services: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerServices'] = UNSET
    design: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Design'] = UNSET
    education: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Education'] = UNSET
    energy: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Energy'] = UNSET
    entertainment: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Entertainment'] = UNSET
    environmental: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Environmental'] = UNSET
    events: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Events'] = UNSET
    farming_agriculture: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FarmingAgriculture'] = UNSET
    finance: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Finance'] = UNSET
    food_beverage: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FoodBeverage'] = UNSET
    gaming: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Gaming'] = UNSET
    government: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Government'] = UNSET
    hardware: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hardware'] = UNSET
    healthcare: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Healthcare'] = UNSET
    hospitality: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hospitality'] = UNSET
    industrials: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Industrials'] = UNSET
    information_technology: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0InformationTechnology'] = UNSET
    insurance: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Insurance'] = UNSET
    legal: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Legal'] = UNSET
    life_sciences: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0LifeSciences'] = UNSET
    logistics: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Logistics'] = UNSET
    manufacturing: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Manufacturing'] = UNSET
    marketing_advertising: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0MarketingAdvertising'] = UNSET
    media: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Media'] = UNSET
    mining: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Mining'] = UNSET
    nonprofit: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Nonprofit'] = UNSET
    publishing: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Publishing'] = UNSET
    real_estate: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0RealEstate'] = UNSET
    retail: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Retail'] = UNSET
    science_engineering: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ScienceEngineering'] = UNSET
    security: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Security'] = UNSET
    software: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Software'] = UNSET
    sports: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Sports'] = UNSET
    telecom: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Telecom'] = UNSET
    trade: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Trade'] = UNSET
    transportation: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Transportation'] = UNSET
    travel_tourism: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0TravelTourism'] = UNSET
    utilities: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Utilities'] = UNSET
    venture_capital: Union[Unset, 'PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0VentureCapital'] = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_security import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Security
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_mining import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Mining
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_farming_agriculture import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FarmingAgriculture
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_real_estate import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0RealEstate
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_travel_tourism import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0TravelTourism
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_publishing import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Publishing
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_artificial_intelligence import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtificialIntelligence
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_construction import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Construction
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_automotive import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Automotive
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_utilities import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Utilities
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_entertainment import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Entertainment
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_energy import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Energy
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_science_engineering import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ScienceEngineering
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_gaming import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Gaming
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_information_technology import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0InformationTechnology
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_nonprofit import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Nonprofit
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_administrative_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AdministrativeServices
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_government import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Government
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_finance import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Finance
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_events import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Events
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_insurance import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Insurance
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_environmental import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Environmental
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_design import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Design
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consumer_goods import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerGoods
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_education import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Education
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_business_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0BusinessServices
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_hospitality import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hospitality
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_hardware import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hardware
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_arts_music import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtsMusic
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_cloud import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Cloud
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_life_sciences import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0LifeSciences
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_software import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Software
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_trade import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Trade
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_media import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Media
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_retail import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Retail
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consulting import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Consulting
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_transportation import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Transportation
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_healthcare import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Healthcare
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_marketing_advertising import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0MarketingAdvertising
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_venture_capital import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0VentureCapital
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_industrials import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Industrials
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_telecom import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Telecom
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_sports import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Sports
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_logistics import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Logistics
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consumer_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerServices
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_manufacturing import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Manufacturing
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_aerospace_military import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AerospaceMilitary
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_food_beverage import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FoodBeverage
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_legal import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Legal
        administrative_services: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.administrative_services, Unset):
            administrative_services = self.administrative_services.to_dict()

        aerospace_military: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.aerospace_military, Unset):
            aerospace_military = self.aerospace_military.to_dict()

        artificial_intelligence: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.artificial_intelligence, Unset):
            artificial_intelligence = self.artificial_intelligence.to_dict()

        arts_music: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.arts_music, Unset):
            arts_music = self.arts_music.to_dict()

        automotive: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.automotive, Unset):
            automotive = self.automotive.to_dict()

        business_services: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.business_services, Unset):
            business_services = self.business_services.to_dict()

        cloud: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cloud, Unset):
            cloud = self.cloud.to_dict()

        construction: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.construction, Unset):
            construction = self.construction.to_dict()

        consulting: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.consulting, Unset):
            consulting = self.consulting.to_dict()

        consumer_goods: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.consumer_goods, Unset):
            consumer_goods = self.consumer_goods.to_dict()

        consumer_services: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.consumer_services, Unset):
            consumer_services = self.consumer_services.to_dict()

        design: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.design, Unset):
            design = self.design.to_dict()

        education: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.education, Unset):
            education = self.education.to_dict()

        energy: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.energy, Unset):
            energy = self.energy.to_dict()

        entertainment: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entertainment, Unset):
            entertainment = self.entertainment.to_dict()

        environmental: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.environmental, Unset):
            environmental = self.environmental.to_dict()

        events: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.events, Unset):
            events = self.events.to_dict()

        farming_agriculture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.farming_agriculture, Unset):
            farming_agriculture = self.farming_agriculture.to_dict()

        finance: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.finance, Unset):
            finance = self.finance.to_dict()

        food_beverage: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.food_beverage, Unset):
            food_beverage = self.food_beverage.to_dict()

        gaming: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gaming, Unset):
            gaming = self.gaming.to_dict()

        government: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.government, Unset):
            government = self.government.to_dict()

        hardware: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hardware, Unset):
            hardware = self.hardware.to_dict()

        healthcare: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.healthcare, Unset):
            healthcare = self.healthcare.to_dict()

        hospitality: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hospitality, Unset):
            hospitality = self.hospitality.to_dict()

        industrials: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.industrials, Unset):
            industrials = self.industrials.to_dict()

        information_technology: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.information_technology, Unset):
            information_technology = self.information_technology.to_dict()

        insurance: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.insurance, Unset):
            insurance = self.insurance.to_dict()

        legal: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.legal, Unset):
            legal = self.legal.to_dict()

        life_sciences: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.life_sciences, Unset):
            life_sciences = self.life_sciences.to_dict()

        logistics: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.logistics, Unset):
            logistics = self.logistics.to_dict()

        manufacturing: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.manufacturing, Unset):
            manufacturing = self.manufacturing.to_dict()

        marketing_advertising: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.marketing_advertising, Unset):
            marketing_advertising = self.marketing_advertising.to_dict()

        media: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.media, Unset):
            media = self.media.to_dict()

        mining: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mining, Unset):
            mining = self.mining.to_dict()

        nonprofit: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nonprofit, Unset):
            nonprofit = self.nonprofit.to_dict()

        publishing: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.publishing, Unset):
            publishing = self.publishing.to_dict()

        real_estate: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.real_estate, Unset):
            real_estate = self.real_estate.to_dict()

        retail: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.retail, Unset):
            retail = self.retail.to_dict()

        science_engineering: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.science_engineering, Unset):
            science_engineering = self.science_engineering.to_dict()

        security: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.security, Unset):
            security = self.security.to_dict()

        software: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.software, Unset):
            software = self.software.to_dict()

        sports: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sports, Unset):
            sports = self.sports.to_dict()

        telecom: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.telecom, Unset):
            telecom = self.telecom.to_dict()

        trade: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.trade, Unset):
            trade = self.trade.to_dict()

        transportation: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.transportation, Unset):
            transportation = self.transportation.to_dict()

        travel_tourism: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.travel_tourism, Unset):
            travel_tourism = self.travel_tourism.to_dict()

        utilities: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.utilities, Unset):
            utilities = self.utilities.to_dict()

        venture_capital: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.venture_capital, Unset):
            venture_capital = self.venture_capital.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if administrative_services is not UNSET:
            field_dict["Administrative Services"] = administrative_services
        if aerospace_military is not UNSET:
            field_dict["Aerospace & Military"] = aerospace_military
        if artificial_intelligence is not UNSET:
            field_dict["Artificial Intelligence"] = artificial_intelligence
        if arts_music is not UNSET:
            field_dict["Arts & Music"] = arts_music
        if automotive is not UNSET:
            field_dict["Automotive"] = automotive
        if business_services is not UNSET:
            field_dict["Business Services"] = business_services
        if cloud is not UNSET:
            field_dict["Cloud"] = cloud
        if construction is not UNSET:
            field_dict["Construction"] = construction
        if consulting is not UNSET:
            field_dict["Consulting"] = consulting
        if consumer_goods is not UNSET:
            field_dict["Consumer Goods"] = consumer_goods
        if consumer_services is not UNSET:
            field_dict["Consumer Services"] = consumer_services
        if design is not UNSET:
            field_dict["Design"] = design
        if education is not UNSET:
            field_dict["Education"] = education
        if energy is not UNSET:
            field_dict["Energy"] = energy
        if entertainment is not UNSET:
            field_dict["Entertainment"] = entertainment
        if environmental is not UNSET:
            field_dict["Environmental"] = environmental
        if events is not UNSET:
            field_dict["Events"] = events
        if farming_agriculture is not UNSET:
            field_dict["Farming & Agriculture"] = farming_agriculture
        if finance is not UNSET:
            field_dict["Finance"] = finance
        if food_beverage is not UNSET:
            field_dict["Food & Beverage"] = food_beverage
        if gaming is not UNSET:
            field_dict["Gaming"] = gaming
        if government is not UNSET:
            field_dict["Government"] = government
        if hardware is not UNSET:
            field_dict["Hardware"] = hardware
        if healthcare is not UNSET:
            field_dict["Healthcare"] = healthcare
        if hospitality is not UNSET:
            field_dict["Hospitality"] = hospitality
        if industrials is not UNSET:
            field_dict["Industrials"] = industrials
        if information_technology is not UNSET:
            field_dict["Information Technology"] = information_technology
        if insurance is not UNSET:
            field_dict["Insurance"] = insurance
        if legal is not UNSET:
            field_dict["Legal"] = legal
        if life_sciences is not UNSET:
            field_dict["Life Sciences"] = life_sciences
        if logistics is not UNSET:
            field_dict["Logistics"] = logistics
        if manufacturing is not UNSET:
            field_dict["Manufacturing"] = manufacturing
        if marketing_advertising is not UNSET:
            field_dict["Marketing & Advertising"] = marketing_advertising
        if media is not UNSET:
            field_dict["Media"] = media
        if mining is not UNSET:
            field_dict["Mining"] = mining
        if nonprofit is not UNSET:
            field_dict["Nonprofit"] = nonprofit
        if publishing is not UNSET:
            field_dict["Publishing"] = publishing
        if real_estate is not UNSET:
            field_dict["Real Estate"] = real_estate
        if retail is not UNSET:
            field_dict["Retail"] = retail
        if science_engineering is not UNSET:
            field_dict["Science & Engineering"] = science_engineering
        if security is not UNSET:
            field_dict["Security"] = security
        if software is not UNSET:
            field_dict["Software"] = software
        if sports is not UNSET:
            field_dict["Sports"] = sports
        if telecom is not UNSET:
            field_dict["Telecom"] = telecom
        if trade is not UNSET:
            field_dict["Trade"] = trade
        if transportation is not UNSET:
            field_dict["Transportation"] = transportation
        if travel_tourism is not UNSET:
            field_dict["Travel & Tourism"] = travel_tourism
        if utilities is not UNSET:
            field_dict["Utilities"] = utilities
        if venture_capital is not UNSET:
            field_dict["Venture Capital"] = venture_capital

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_security import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Security
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_mining import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Mining
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_farming_agriculture import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FarmingAgriculture
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_real_estate import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0RealEstate
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_travel_tourism import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0TravelTourism
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_publishing import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Publishing
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_artificial_intelligence import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtificialIntelligence
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_construction import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Construction
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_automotive import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Automotive
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_utilities import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Utilities
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_entertainment import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Entertainment
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_energy import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Energy
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_science_engineering import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ScienceEngineering
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_gaming import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Gaming
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_information_technology import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0InformationTechnology
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_nonprofit import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Nonprofit
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_administrative_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AdministrativeServices
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_government import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Government
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_finance import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Finance
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_events import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Events
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_insurance import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Insurance
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_environmental import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Environmental
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_design import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Design
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consumer_goods import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerGoods
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_education import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Education
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_business_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0BusinessServices
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_hospitality import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hospitality
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_hardware import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hardware
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_arts_music import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtsMusic
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_cloud import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Cloud
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_life_sciences import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0LifeSciences
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_software import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Software
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_trade import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Trade
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_media import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Media
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_retail import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Retail
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consulting import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Consulting
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_transportation import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Transportation
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_healthcare import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Healthcare
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_marketing_advertising import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0MarketingAdvertising
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_venture_capital import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0VentureCapital
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_industrials import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Industrials
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_telecom import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Telecom
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_sports import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Sports
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_logistics import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Logistics
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_consumer_services import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerServices
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_manufacturing import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Manufacturing
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_aerospace_military import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AerospaceMilitary
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_food_beverage import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FoodBeverage
        from ..models.poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0_legal import PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Legal
        d = dict(src_dict)
        _administrative_services = d.pop("Administrative Services", UNSET)
        administrative_services: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AdministrativeServices]
        if isinstance(_administrative_services,  Unset):
            administrative_services = UNSET
        else:
            administrative_services = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AdministrativeServices.from_dict(_administrative_services)




        _aerospace_military = d.pop("Aerospace & Military", UNSET)
        aerospace_military: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AerospaceMilitary]
        if isinstance(_aerospace_military,  Unset):
            aerospace_military = UNSET
        else:
            aerospace_military = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0AerospaceMilitary.from_dict(_aerospace_military)




        _artificial_intelligence = d.pop("Artificial Intelligence", UNSET)
        artificial_intelligence: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtificialIntelligence]
        if isinstance(_artificial_intelligence,  Unset):
            artificial_intelligence = UNSET
        else:
            artificial_intelligence = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtificialIntelligence.from_dict(_artificial_intelligence)




        _arts_music = d.pop("Arts & Music", UNSET)
        arts_music: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtsMusic]
        if isinstance(_arts_music,  Unset):
            arts_music = UNSET
        else:
            arts_music = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ArtsMusic.from_dict(_arts_music)




        _automotive = d.pop("Automotive", UNSET)
        automotive: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Automotive]
        if isinstance(_automotive,  Unset):
            automotive = UNSET
        else:
            automotive = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Automotive.from_dict(_automotive)




        _business_services = d.pop("Business Services", UNSET)
        business_services: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0BusinessServices]
        if isinstance(_business_services,  Unset):
            business_services = UNSET
        else:
            business_services = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0BusinessServices.from_dict(_business_services)




        _cloud = d.pop("Cloud", UNSET)
        cloud: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Cloud]
        if isinstance(_cloud,  Unset):
            cloud = UNSET
        else:
            cloud = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Cloud.from_dict(_cloud)




        _construction = d.pop("Construction", UNSET)
        construction: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Construction]
        if isinstance(_construction,  Unset):
            construction = UNSET
        else:
            construction = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Construction.from_dict(_construction)




        _consulting = d.pop("Consulting", UNSET)
        consulting: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Consulting]
        if isinstance(_consulting,  Unset):
            consulting = UNSET
        else:
            consulting = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Consulting.from_dict(_consulting)




        _consumer_goods = d.pop("Consumer Goods", UNSET)
        consumer_goods: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerGoods]
        if isinstance(_consumer_goods,  Unset):
            consumer_goods = UNSET
        else:
            consumer_goods = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerGoods.from_dict(_consumer_goods)




        _consumer_services = d.pop("Consumer Services", UNSET)
        consumer_services: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerServices]
        if isinstance(_consumer_services,  Unset):
            consumer_services = UNSET
        else:
            consumer_services = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ConsumerServices.from_dict(_consumer_services)




        _design = d.pop("Design", UNSET)
        design: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Design]
        if isinstance(_design,  Unset):
            design = UNSET
        else:
            design = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Design.from_dict(_design)




        _education = d.pop("Education", UNSET)
        education: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Education]
        if isinstance(_education,  Unset):
            education = UNSET
        else:
            education = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Education.from_dict(_education)




        _energy = d.pop("Energy", UNSET)
        energy: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Energy]
        if isinstance(_energy,  Unset):
            energy = UNSET
        else:
            energy = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Energy.from_dict(_energy)




        _entertainment = d.pop("Entertainment", UNSET)
        entertainment: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Entertainment]
        if isinstance(_entertainment,  Unset):
            entertainment = UNSET
        else:
            entertainment = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Entertainment.from_dict(_entertainment)




        _environmental = d.pop("Environmental", UNSET)
        environmental: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Environmental]
        if isinstance(_environmental,  Unset):
            environmental = UNSET
        else:
            environmental = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Environmental.from_dict(_environmental)




        _events = d.pop("Events", UNSET)
        events: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Events]
        if isinstance(_events,  Unset):
            events = UNSET
        else:
            events = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Events.from_dict(_events)




        _farming_agriculture = d.pop("Farming & Agriculture", UNSET)
        farming_agriculture: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FarmingAgriculture]
        if isinstance(_farming_agriculture,  Unset):
            farming_agriculture = UNSET
        else:
            farming_agriculture = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FarmingAgriculture.from_dict(_farming_agriculture)




        _finance = d.pop("Finance", UNSET)
        finance: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Finance]
        if isinstance(_finance,  Unset):
            finance = UNSET
        else:
            finance = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Finance.from_dict(_finance)




        _food_beverage = d.pop("Food & Beverage", UNSET)
        food_beverage: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FoodBeverage]
        if isinstance(_food_beverage,  Unset):
            food_beverage = UNSET
        else:
            food_beverage = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0FoodBeverage.from_dict(_food_beverage)




        _gaming = d.pop("Gaming", UNSET)
        gaming: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Gaming]
        if isinstance(_gaming,  Unset):
            gaming = UNSET
        else:
            gaming = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Gaming.from_dict(_gaming)




        _government = d.pop("Government", UNSET)
        government: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Government]
        if isinstance(_government,  Unset):
            government = UNSET
        else:
            government = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Government.from_dict(_government)




        _hardware = d.pop("Hardware", UNSET)
        hardware: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hardware]
        if isinstance(_hardware,  Unset):
            hardware = UNSET
        else:
            hardware = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hardware.from_dict(_hardware)




        _healthcare = d.pop("Healthcare", UNSET)
        healthcare: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Healthcare]
        if isinstance(_healthcare,  Unset):
            healthcare = UNSET
        else:
            healthcare = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Healthcare.from_dict(_healthcare)




        _hospitality = d.pop("Hospitality", UNSET)
        hospitality: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hospitality]
        if isinstance(_hospitality,  Unset):
            hospitality = UNSET
        else:
            hospitality = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Hospitality.from_dict(_hospitality)




        _industrials = d.pop("Industrials", UNSET)
        industrials: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Industrials]
        if isinstance(_industrials,  Unset):
            industrials = UNSET
        else:
            industrials = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Industrials.from_dict(_industrials)




        _information_technology = d.pop("Information Technology", UNSET)
        information_technology: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0InformationTechnology]
        if isinstance(_information_technology,  Unset):
            information_technology = UNSET
        else:
            information_technology = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0InformationTechnology.from_dict(_information_technology)




        _insurance = d.pop("Insurance", UNSET)
        insurance: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Insurance]
        if isinstance(_insurance,  Unset):
            insurance = UNSET
        else:
            insurance = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Insurance.from_dict(_insurance)




        _legal = d.pop("Legal", UNSET)
        legal: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Legal]
        if isinstance(_legal,  Unset):
            legal = UNSET
        else:
            legal = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Legal.from_dict(_legal)




        _life_sciences = d.pop("Life Sciences", UNSET)
        life_sciences: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0LifeSciences]
        if isinstance(_life_sciences,  Unset):
            life_sciences = UNSET
        else:
            life_sciences = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0LifeSciences.from_dict(_life_sciences)




        _logistics = d.pop("Logistics", UNSET)
        logistics: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Logistics]
        if isinstance(_logistics,  Unset):
            logistics = UNSET
        else:
            logistics = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Logistics.from_dict(_logistics)




        _manufacturing = d.pop("Manufacturing", UNSET)
        manufacturing: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Manufacturing]
        if isinstance(_manufacturing,  Unset):
            manufacturing = UNSET
        else:
            manufacturing = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Manufacturing.from_dict(_manufacturing)




        _marketing_advertising = d.pop("Marketing & Advertising", UNSET)
        marketing_advertising: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0MarketingAdvertising]
        if isinstance(_marketing_advertising,  Unset):
            marketing_advertising = UNSET
        else:
            marketing_advertising = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0MarketingAdvertising.from_dict(_marketing_advertising)




        _media = d.pop("Media", UNSET)
        media: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Media]
        if isinstance(_media,  Unset):
            media = UNSET
        else:
            media = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Media.from_dict(_media)




        _mining = d.pop("Mining", UNSET)
        mining: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Mining]
        if isinstance(_mining,  Unset):
            mining = UNSET
        else:
            mining = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Mining.from_dict(_mining)




        _nonprofit = d.pop("Nonprofit", UNSET)
        nonprofit: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Nonprofit]
        if isinstance(_nonprofit,  Unset):
            nonprofit = UNSET
        else:
            nonprofit = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Nonprofit.from_dict(_nonprofit)




        _publishing = d.pop("Publishing", UNSET)
        publishing: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Publishing]
        if isinstance(_publishing,  Unset):
            publishing = UNSET
        else:
            publishing = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Publishing.from_dict(_publishing)




        _real_estate = d.pop("Real Estate", UNSET)
        real_estate: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0RealEstate]
        if isinstance(_real_estate,  Unset):
            real_estate = UNSET
        else:
            real_estate = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0RealEstate.from_dict(_real_estate)




        _retail = d.pop("Retail", UNSET)
        retail: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Retail]
        if isinstance(_retail,  Unset):
            retail = UNSET
        else:
            retail = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Retail.from_dict(_retail)




        _science_engineering = d.pop("Science & Engineering", UNSET)
        science_engineering: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ScienceEngineering]
        if isinstance(_science_engineering,  Unset):
            science_engineering = UNSET
        else:
            science_engineering = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0ScienceEngineering.from_dict(_science_engineering)




        _security = d.pop("Security", UNSET)
        security: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Security]
        if isinstance(_security,  Unset):
            security = UNSET
        else:
            security = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Security.from_dict(_security)




        _software = d.pop("Software", UNSET)
        software: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Software]
        if isinstance(_software,  Unset):
            software = UNSET
        else:
            software = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Software.from_dict(_software)




        _sports = d.pop("Sports", UNSET)
        sports: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Sports]
        if isinstance(_sports,  Unset):
            sports = UNSET
        else:
            sports = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Sports.from_dict(_sports)




        _telecom = d.pop("Telecom", UNSET)
        telecom: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Telecom]
        if isinstance(_telecom,  Unset):
            telecom = UNSET
        else:
            telecom = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Telecom.from_dict(_telecom)




        _trade = d.pop("Trade", UNSET)
        trade: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Trade]
        if isinstance(_trade,  Unset):
            trade = UNSET
        else:
            trade = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Trade.from_dict(_trade)




        _transportation = d.pop("Transportation", UNSET)
        transportation: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Transportation]
        if isinstance(_transportation,  Unset):
            transportation = UNSET
        else:
            transportation = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Transportation.from_dict(_transportation)




        _travel_tourism = d.pop("Travel & Tourism", UNSET)
        travel_tourism: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0TravelTourism]
        if isinstance(_travel_tourism,  Unset):
            travel_tourism = UNSET
        else:
            travel_tourism = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0TravelTourism.from_dict(_travel_tourism)




        _utilities = d.pop("Utilities", UNSET)
        utilities: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Utilities]
        if isinstance(_utilities,  Unset):
            utilities = UNSET
        else:
            utilities = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0Utilities.from_dict(_utilities)




        _venture_capital = d.pop("Venture Capital", UNSET)
        venture_capital: Union[Unset, PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0VentureCapital]
        if isinstance(_venture_capital,  Unset):
            venture_capital = UNSET
        else:
            venture_capital = PollCombinedSearchResponse200OutputDataType0ItemsItemLiJobPostsStatsType0StandardIndustriesStatsType0VentureCapital.from_dict(_venture_capital)




        poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0 = cls(
            administrative_services=administrative_services,
            aerospace_military=aerospace_military,
            artificial_intelligence=artificial_intelligence,
            arts_music=arts_music,
            automotive=automotive,
            business_services=business_services,
            cloud=cloud,
            construction=construction,
            consulting=consulting,
            consumer_goods=consumer_goods,
            consumer_services=consumer_services,
            design=design,
            education=education,
            energy=energy,
            entertainment=entertainment,
            environmental=environmental,
            events=events,
            farming_agriculture=farming_agriculture,
            finance=finance,
            food_beverage=food_beverage,
            gaming=gaming,
            government=government,
            hardware=hardware,
            healthcare=healthcare,
            hospitality=hospitality,
            industrials=industrials,
            information_technology=information_technology,
            insurance=insurance,
            legal=legal,
            life_sciences=life_sciences,
            logistics=logistics,
            manufacturing=manufacturing,
            marketing_advertising=marketing_advertising,
            media=media,
            mining=mining,
            nonprofit=nonprofit,
            publishing=publishing,
            real_estate=real_estate,
            retail=retail,
            science_engineering=science_engineering,
            security=security,
            software=software,
            sports=sports,
            telecom=telecom,
            trade=trade,
            transportation=transportation,
            travel_tourism=travel_tourism,
            utilities=utilities,
            venture_capital=venture_capital,
        )

        return poll_combined_search_response_200_output_data_type_0_items_item_li_job_posts_stats_type_0_standard_industries_stats_type_0




from enum import Enum

class CompanySearchBodySearchParamsJobPostingStatsType0AnyOfType0ItemType4RangeType0Type(str, Enum):
    COUNT_RANGE = "count-range"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_engagement_type_0_reactions_by_type_type_0_item import CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0ReactionsByTypeType0Item





T = TypeVar("T", bound="CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0")



@_attrs_define
class CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0:
    """ 
        Attributes:
            num_comments (Union[None, Unset, float]):
            num_shares (Union[None, Unset, float]):
            num_reactions (Union[None, Unset, float]):
            reactions_by_type (Union[None, Unset, list['CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0Engag
                ementType0ReactionsByTypeType0Item']]):
     """

    num_comments: Union[None, Unset, float] = UNSET
    num_shares: Union[None, Unset, float] = UNSET
    num_reactions: Union[None, Unset, float] = UNSET
    reactions_by_type: Union[None, Unset, list['CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0ReactionsByTypeType0Item']] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_engagement_type_0_reactions_by_type_type_0_item import CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0ReactionsByTypeType0Item
        num_comments: Union[None, Unset, float]
        if isinstance(self.num_comments, Unset):
            num_comments = UNSET
        else:
            num_comments = self.num_comments

        num_shares: Union[None, Unset, float]
        if isinstance(self.num_shares, Unset):
            num_shares = UNSET
        else:
            num_shares = self.num_shares

        num_reactions: Union[None, Unset, float]
        if isinstance(self.num_reactions, Unset):
            num_reactions = UNSET
        else:
            num_reactions = self.num_reactions

        reactions_by_type: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.reactions_by_type, Unset):
            reactions_by_type = UNSET
        elif isinstance(self.reactions_by_type, list):
            reactions_by_type = []
            for reactions_by_type_type_0_item_data in self.reactions_by_type:
                reactions_by_type_type_0_item = reactions_by_type_type_0_item_data.to_dict()
                reactions_by_type.append(reactions_by_type_type_0_item)


        else:
            reactions_by_type = self.reactions_by_type


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if num_comments is not UNSET:
            field_dict["numComments"] = num_comments
        if num_shares is not UNSET:
            field_dict["numShares"] = num_shares
        if num_reactions is not UNSET:
            field_dict["numReactions"] = num_reactions
        if reactions_by_type is not UNSET:
            field_dict["reactionsByType"] = reactions_by_type

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_engagement_type_0_reactions_by_type_type_0_item import CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0ReactionsByTypeType0Item
        d = dict(src_dict)
        def _parse_num_comments(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        num_comments = _parse_num_comments(d.pop("numComments", UNSET))


        def _parse_num_shares(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        num_shares = _parse_num_shares(d.pop("numShares", UNSET))


        def _parse_num_reactions(data: object) -> Union[None, Unset, float]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, float], data)

        num_reactions = _parse_num_reactions(d.pop("numReactions", UNSET))


        def _parse_reactions_by_type(data: object) -> Union[None, Unset, list['CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0ReactionsByTypeType0Item']]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                reactions_by_type_type_0 = []
                _reactions_by_type_type_0 = data
                for reactions_by_type_type_0_item_data in (_reactions_by_type_type_0):
                    reactions_by_type_type_0_item = CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0ReactionsByTypeType0Item.from_dict(reactions_by_type_type_0_item_data)



                    reactions_by_type_type_0.append(reactions_by_type_type_0_item)

                return reactions_by_type_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list['CompanyPostsLiveFetchResponse200OutputDataItemResharedPostType0EngagementType0ReactionsByTypeType0Item']], data)

        reactions_by_type = _parse_reactions_by_type(d.pop("reactionsByType", UNSET))


        company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_engagement_type_0 = cls(
            num_comments=num_comments,
            num_shares=num_shares,
            num_reactions=num_reactions,
            reactions_by_type=reactions_by_type,
        )


        company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_engagement_type_0.additional_properties = d
        return company_posts_live_fetch_response_200_output_data_item_reshared_post_type_0_engagement_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="KitchenSinkProfileResponse200OutputDataItemPatentsType0Item")



@_attrs_define
class KitchenSinkProfileResponse200OutputDataItemPatentsType0Item:
    """ 
        Attributes:
            id (Union[None, Unset, str]):
            title (Union[None, Unset, str]):
            country (Union[None, Unset, str]):
            number (Union[None, Unset, str]):
            description (Union[None, Unset, str]):
            url (Union[None, Unset, str]):
            date (Union[None, Unset, str]):
     """

    id: Union[None, Unset, str] = UNSET
    title: Union[None, Unset, str] = UNSET
    country: Union[None, Unset, str] = UNSET
    number: Union[None, Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    url: Union[None, Unset, str] = UNSET
    date: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        id: Union[None, Unset, str]
        if isinstance(self.id, Unset):
            id = UNSET
        else:
            id = self.id

        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        country: Union[None, Unset, str]
        if isinstance(self.country, Unset):
            country = UNSET
        else:
            country = self.country

        number: Union[None, Unset, str]
        if isinstance(self.number, Unset):
            number = UNSET
        else:
            number = self.number

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        url: Union[None, Unset, str]
        if isinstance(self.url, Unset):
            url = UNSET
        else:
            url = self.url

        date: Union[None, Unset, str]
        if isinstance(self.date, Unset):
            date = UNSET
        else:
            date = self.date


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if id is not UNSET:
            field_dict["id"] = id
        if title is not UNSET:
            field_dict["title"] = title
        if country is not UNSET:
            field_dict["country"] = country
        if number is not UNSET:
            field_dict["number"] = number
        if description is not UNSET:
            field_dict["description"] = description
        if url is not UNSET:
            field_dict["url"] = url
        if date is not UNSET:
            field_dict["date"] = date

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        id = _parse_id(d.pop("id", UNSET))


        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))


        def _parse_country(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        country = _parse_country(d.pop("country", UNSET))


        def _parse_number(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        number = _parse_number(d.pop("number", UNSET))


        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))


        def _parse_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        url = _parse_url(d.pop("url", UNSET))


        def _parse_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        date = _parse_date(d.pop("date", UNSET))


        kitchen_sink_profile_response_200_output_data_item_patents_type_0_item = cls(
            id=id,
            title=title,
            country=country,
            number=number,
            description=description,
            url=url,
            date=date,
        )


        kitchen_sink_profile_response_200_output_data_item_patents_type_0_item.additional_properties = d
        return kitchen_sink_profile_response_200_output_data_item_patents_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.investment_search_body_search_params_type_0_sorting_type_0_direction import InvestmentSearchBodySearchParamsType0SortingType0Direction
from ..models.investment_search_body_search_params_type_0_sorting_type_0_field import InvestmentSearchBodySearchParamsType0SortingType0Field
from ..types import UNSET, Unset
from typing import Union






T = TypeVar("T", bound="InvestmentSearchBodySearchParamsType0SortingType0")



@_attrs_define
class InvestmentSearchBodySearchParamsType0SortingType0:
    """ Sorting configuration. If provided, field is required. Defaults to round_date DESC if not provided.

        Attributes:
            field (InvestmentSearchBodySearchParamsType0SortingType0Field): Field to sort by. Options: 'round_date'
                (default), 'raised_amount_usd', 'company_name', 'investor_name'
            direction (Union[Unset, InvestmentSearchBodySearchParamsType0SortingType0Direction]): Sort order - asc or desc
                (defaults to desc) Default: InvestmentSearchBodySearchParamsType0SortingType0Direction.DESC.
     """

    field: InvestmentSearchBodySearchParamsType0SortingType0Field
    direction: Union[Unset, InvestmentSearchBodySearchParamsType0SortingType0Direction] = InvestmentSearchBodySearchParamsType0SortingType0Direction.DESC
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        field = self.field.value

        direction: Union[Unset, str] = UNSET
        if not isinstance(self.direction, Unset):
            direction = self.direction.value



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "field": field,
        })
        if direction is not UNSET:
            field_dict["direction"] = direction

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        field = InvestmentSearchBodySearchParamsType0SortingType0Field(d.pop("field"))




        _direction = d.pop("direction", UNSET)
        direction: Union[Unset, InvestmentSearchBodySearchParamsType0SortingType0Direction]
        if isinstance(_direction,  Unset):
            direction = UNSET
        else:
            direction = InvestmentSearchBodySearchParamsType0SortingType0Direction(_direction)




        investment_search_body_search_params_type_0_sorting_type_0 = cls(
            field=field,
            direction=direction,
        )


        investment_search_body_search_params_type_0_sorting_type_0.additional_properties = d
        return investment_search_body_search_params_type_0_sorting_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class PeopleSearchCountBodySearchParamsJobTitleV2Type0NoneOfType0ItemType2GroupsItem(str, Enum):
    ASSISTANT = "assistant"
    DIRECTOR = "director"
    ENTRY_LEVEL = "entry-level"
    INTERN = "intern"
    MANAGEMENT = "management"
    VP = "vp"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="GetSavedSearchRunProfilesResponse200OutputProfilesItemProfileLanguagesType0Item")



@_attrs_define
class GetSavedSearchRunProfilesResponse200OutputProfilesItemProfileLanguagesType0Item:
    """ 
        Attributes:
            name (Union[None, Unset, str]):
            proficiency_id (Union[None, Unset, str]):
            proficiency_name (Union[None, Unset, str]):
     """

    name: Union[None, Unset, str] = UNSET
    proficiency_id: Union[None, Unset, str] = UNSET
    proficiency_name: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        proficiency_id: Union[None, Unset, str]
        if isinstance(self.proficiency_id, Unset):
            proficiency_id = UNSET
        else:
            proficiency_id = self.proficiency_id

        proficiency_name: Union[None, Unset, str]
        if isinstance(self.proficiency_name, Unset):
            proficiency_name = UNSET
        else:
            proficiency_name = self.proficiency_name


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if name is not UNSET:
            field_dict["name"] = name
        if proficiency_id is not UNSET:
            field_dict["proficiency_id"] = proficiency_id
        if proficiency_name is not UNSET:
            field_dict["proficiency_name"] = proficiency_name

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))


        def _parse_proficiency_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        proficiency_id = _parse_proficiency_id(d.pop("proficiency_id", UNSET))


        def _parse_proficiency_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        proficiency_name = _parse_proficiency_name(d.pop("proficiency_name", UNSET))


        get_saved_search_run_profiles_response_200_output_profiles_item_profile_languages_type_0_item = cls(
            name=name,
            proficiency_id=proficiency_id,
            proficiency_name=proficiency_name,
        )


        get_saved_search_run_profiles_response_200_output_profiles_item_profile_languages_type_0_item.additional_properties = d
        return get_saved_search_run_profiles_response_200_output_profiles_item_profile_languages_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.get_current_companies_in_saved_search_body_statuses_type_0_item import GetCurrentCompaniesInSavedSearchBodyStatusesType0Item
from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="GetCurrentCompaniesInSavedSearchBody")



@_attrs_define
class GetCurrentCompaniesInSavedSearchBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            saved_search_id (str): The ID of the saved search
            statuses (Union[None, Unset, list[GetCurrentCompaniesInSavedSearchBodyStatusesType0Item]]): The statuses of the
                companies. This is optional and if not provided, all current companies will be returned.
            cursor (Union[None, Unset, str]): The cursor to start from
            page_size (Union[Unset, int]): The number of companies to return Default: 25.
     """

    api_key: str
    saved_search_id: str
    statuses: Union[None, Unset, list[GetCurrentCompaniesInSavedSearchBodyStatusesType0Item]] = UNSET
    cursor: Union[None, Unset, str] = UNSET
    page_size: Union[Unset, int] = 25
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        api_key = self.api_key

        saved_search_id = self.saved_search_id

        statuses: Union[None, Unset, list[str]]
        if isinstance(self.statuses, Unset):
            statuses = UNSET
        elif isinstance(self.statuses, list):
            statuses = []
            for statuses_type_0_item_data in self.statuses:
                statuses_type_0_item = statuses_type_0_item_data.value
                statuses.append(statuses_type_0_item)


        else:
            statuses = self.statuses

        cursor: Union[None, Unset, str]
        if isinstance(self.cursor, Unset):
            cursor = UNSET
        else:
            cursor = self.cursor

        page_size = self.page_size


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
            "savedSearchId": saved_search_id,
        })
        if statuses is not UNSET:
            field_dict["statuses"] = statuses
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if page_size is not UNSET:
            field_dict["pageSize"] = page_size

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        saved_search_id = d.pop("savedSearchId")

        def _parse_statuses(data: object) -> Union[None, Unset, list[GetCurrentCompaniesInSavedSearchBodyStatusesType0Item]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                statuses_type_0 = []
                _statuses_type_0 = data
                for statuses_type_0_item_data in (_statuses_type_0):
                    statuses_type_0_item = GetCurrentCompaniesInSavedSearchBodyStatusesType0Item(statuses_type_0_item_data)



                    statuses_type_0.append(statuses_type_0_item)

                return statuses_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[GetCurrentCompaniesInSavedSearchBodyStatusesType0Item]], data)

        statuses = _parse_statuses(d.pop("statuses", UNSET))


        def _parse_cursor(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cursor = _parse_cursor(d.pop("cursor", UNSET))


        page_size = d.pop("pageSize", UNSET)

        get_current_companies_in_saved_search_body = cls(
            api_key=api_key,
            saved_search_id=saved_search_id,
            statuses=statuses,
            cursor=cursor,
            page_size=page_size,
        )


        get_current_companies_in_saved_search_body.additional_properties = d
        return get_current_companies_in_saved_search_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchResponse200OutputCompaniesItemRoleCountMatchesType0ItemNumMatchingEmployeesType2Type(str, Enum):
    NONE = "none"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TextToProfileSearchResponse200OutputSearchParamsEducationType0AllOfType0ItemSchoolV3Type0AnyOfType0ItemSourceType2Type1(str, Enum):
    CSV = "csv"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class KitchenSinkProfileResponse200OutputDataItemDetailedWorkExperiencesType0ItemSeniorityType2Type1(str, Enum):
    ASSOCIATE = "Associate"
    DIRECTOR = "Director"
    ENTRY_LEVEL = "Entry level"
    EXECUTIVE = "Executive"
    INTERNSHIP = "Internship"
    MID_SENIOR_LEVEL = "Mid-Senior level"

    def __str__(self) -> str:
        return str(self.value)
